==> bfilter-0.10.1.tar.gz: bfilter-0.10.1/main/gui/win32/LogWidget.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef LOGWIDGET_H_
#define LOGWIDGET_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "LogObserver.h"
#include <ace/config.h>
#include <wx/textctrl.h>

class Log;
class StyledText;

class LogWidget : public wxTextCtrl, private LogObserver
{
public:
	LogWidget(
		Log* log, wxWindow* parent, wxWindowID id,
		wxString const& value = wxEmptyString,
		wxPoint const& pos = wxDefaultPosition,
		wxSize const& size = wxDefaultSize,
		long style = wxTE_MULTILINE|wxTE_READONLY|wxTE_RICH,
		wxValidator const& validator = wxDefaultValidator,
		wxString const& name = wxTextCtrlNameStr);
	
	virtual ~LogWidget();
private:
	virtual void appendText(StyledText const& text);

	virtual void clear();
	
	void doAppendText(StyledText const& text);

	void loadTextFromLog();
	
	Log* m_pLog;
};

#endif

==> bfilter_1.0.2.orig.tar.gz: bfilter-1.0.2/main/gui/win32/LogWidget.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef LOGWIDGET_H_
#define LOGWIDGET_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "LogObserver.h"
#include <ace/config-lite.h>
#include <wx/textctrl.h>

class Log;
class StyledText;

class LogWidget : public wxTextCtrl, private LogObserver
{
public:
	LogWidget(
		Log* log, wxWindow* parent, wxWindowID id,
		wxString const& value = wxEmptyString,
		wxPoint const& pos = wxDefaultPosition,
		wxSize const& size = wxDefaultSize,
		long style = wxTE_MULTILINE|wxTE_READONLY|wxTE_RICH,
		wxValidator const& validator = wxDefaultValidator,
		wxString const& name = wxTextCtrlNameStr);
	
	virtual ~LogWidget();
private:
	virtual void appendText(StyledText const& text);

	virtual void clear();
	
	void doAppendText(StyledText const& text);

	void loadTextFromLog();
	
	Log* m_pLog;
};

#endif
